@@ -93,54 +93,34 @@ class PrestoFilter(MenuFilter):
         return filtered_conversations
 
     def __does_customer_order_any_item(self, conversations):
-        examples = [
-            {
-                "prompt": "AI1: <welcome>\nAI2: Can I get you an iced drink today?\nCX: Yeah.\nAI2: Got it.\nAI1: What can we make fresh for your today?\nCX: I want a Bean & Cheese Burrito with Green sauce.\nAI1: Got it.\nAI2: Can I get a Bean & Cheese Burrito with green sauce?\nAI1: Sure.\nAI2: Got it..",
-                "completion": "1x Bean & Cheese Burrito with Green Sauce",
-                "is_yes": True
-            },
-            {
-                "prompt": "AI1: <welcome>\nCX1: I'm sorry, I'm not sure what you're saying.\nAI1: Can I get you an icked cold drink today?\nCX1: I'm sorry. I'm not sure what you're asking.\nAI1: Can I order you an icked cold drink today.\nCX1: I'm sorry I'm not sure what you're talking about.\nAI1: Can I please get you an icked cold drink.\nCX1: I'm not sure what you're trying to say.\nAI1: Can I have an icked cold drink.",
-                "completion": "1x Bean & Cheese Burrito with Green Sauce",
-                "is_yes": False
-            },
-            {"prompt": "\nCX: Hello.\nAI (reading back): <welcome>\nCX: I'm sorry.\nAI: Order when ready.\nCX: I'm sorry. I'm sorry.\nAI: Okay.\nCX: I'm sorry, I'm sorry.\nAI: I'm sorry.\nCX: I'm sorry I'm sorry.\nAI: You're sorry?\nCX: I'm sorry. You're sorry?\nAI: I'm sorry. I'm so sorry.\nCX: I'm so sorry.\nAI: I'm so sorry.\nCX (reading back): I'm sorry",
-                "completion": "1x Bean & Cheese Burrito with Green Sauce",
-                "is_yes": False
-             }
-        ]
+        examples = [{"prompt": "AI1: <welcome>\nAI2: Can I get you an iced drink today?\nCX: Yeah.\nAI2: Got it.\nAI1: What can we make fresh for your today?\nCX: I want a Bean & Cheese Burrito with Green sauce.\nAI1: Got it.\nAI2: Can I get a Bean & Cheese Burrito with green sauce?\nAI1: Sure.\nAI2: Got it..",
+                     "completion": "1x Bean & Cheese Burrito with Green Sauce",
+                     "is_yes": True},
+                    {"prompt": "AI1: <welcome>\nCX1: I'm sorry, I'm not sure what you're saying.\nAI1: Can I get you an icked cold drink today?\nCX1: I'm sorry. I'm not sure what you're asking.\nAI1: Can I order you an icked cold drink today.\nCX1: I'm sorry I'm not sure what you're talking about.\nAI1: Can I please get you an icked cold drink.\nCX1: I'm not sure what you're trying to say.\nAI1: Can I have an icked cold drink.",
+                     "completion": "1x Bean & Cheese Burrito with Green Sauce",
+                     "is_yes": False},
+                    {"prompt": "\nCX: Hello.\nAI (reading back): <welcome>\nCX: I'm sorry.\nAI: Order when ready.\nCX: I'm sorry. I'm sorry.\nAI: Okay.\nCX: I'm sorry, I'm sorry.\nAI: I'm sorry.\nCX: I'm sorry I'm sorry.\nAI: You're sorry?\nCX: I'm sorry. You're sorry?\nAI: I'm sorry. I'm so sorry.\nCX: I'm so sorry.\nAI: I'm so sorry.\nCX (reading back): I'm sorry",
+                     "completion": "1x Bean & Cheese Burrito with Green Sauce",
+                     "is_yes": False}]
 
         return self.__filter_question("Does the customer order any item?", conversations, examples, None)
 
     def __does_customer_order_this_item(self, conversations):
-        examples = [
-            {
-                "prompt": "\nCX: <welcome>\nAI: Ohh.. Like it?.\nCX: Yeah.\nAI: Okay, I'll have a large French fry.\nCX: Okay, I'll have a medium French fry.\nAI: Okay, I have it.\nCX: Can I get a large French fry?\nAI: Okay, I have that.\nCX: Can I get an iced cold drink?\nAI: Okay, I'll get you a large Sprite.\nCX: Okay, I have it. What else?\nAI: What else?\nCX: What's that?\n",
-                "completion": "1x Bean & Cheese Burrito with Green Sauce",
-                "is_yes": False
-            },
-            {
-                "prompt": "\nCX: I'm sorry, I don't understand.\nAI: What would you like?\nCX: The Del Taco.\nAI: What would you prefer?\nCX: The Del Tako.\nAI: What would you rather have?\nCX: The Del Tato.\nAI: What would you have?\nCX: The Del Tac.\nAI: What would you order?\nCX: The Del Tacoo.\nAI: What would you want?\nCX: The Del Tacu.\nAI: What would you choose?\nCX: The Del Tacuu.\nAI: What",
-                "completion": "1x The Del Taco",
-                "is_yes": True
-            },
-            {
-                "prompt": "CX: Can I get you a Sprite?\nAI: Sure, I'll have a Sprite.\nCX: Can I get you Sprite?\nAI: Sure.\nCX: Can I get Sprite?\nAI: Sure..\nCX: Can I get Spray?\nAI: Sure..",
-                "completion": "1x Bean & Cheese Burrito with Green Sauce",
-                "is_yes": False
-            },
-            {
-                "prompt": "AI1: <welcome>\nAI2: Can I get you an iced drink today?\nCX: Yeah.\nAI2: Got it.\nAI1: What can we make fresh for your today?\nCX: I want a Bean & Cheese Burrito with Green sauce.\nAI1: Got it.\nAI2: Can I get a Bean & Cheese Burrito with green sauce?\nAI1: Sure.\nAI2: Got it..",
-                "completion": "1x Bean & Cheese Burrito with Green Sauce",
-                "is_yes": True
-            },
-            {
-                "prompt": "CX: <welcome>\nAI: Hi, can I help you?\nCX: Yes, I'd like to talk to a live person.\nAI: Okay, I'll be right back.",
-                "completion": "1x Bean & Cheese Burrito with Green Sauce",
-                "is_yes": False
-            }
-
-        ]
+        examples = [{"prompt": "\nCX: <welcome>\nAI: Ohh.. Like it?.\nCX: Yeah.\nAI: Okay, I'll have a large French fry.\nCX: Okay, I'll have a medium French fry.\nAI: Okay, I have it.\nCX: Can I get a large French fry?\nAI: Okay, I have that.\nCX: Can I get an iced cold drink?\nAI: Okay, I'll get you a large Sprite.\nCX: Okay, I have it. What else?\nAI: What else?\nCX: What's that?\n",
+                     "completion": "1x Bean & Cheese Burrito with Green Sauce",
+                     "is_yes": False},
+                    {"prompt": "\nCX: I'm sorry, I don't understand.\nAI: What would you like?\nCX: The Del Taco.\nAI: What would you prefer?\nCX: The Del Tako.\nAI: What would you rather have?\nCX: The Del Tato.\nAI: What would you have?\nCX: The Del Tac.\nAI: What would you order?\nCX: The Del Tacoo.\nAI: What would you want?\nCX: The Del Tacu.\nAI: What would you choose?\nCX: The Del Tacuu.\nAI: What",
+                     "completion": "1x The Del Taco",
+                     "is_yes": True},
+                    {"prompt": "CX: Can I get you a Sprite?\nAI: Sure, I'll have a Sprite.\nCX: Can I get you Sprite?\nAI: Sure.\nCX: Can I get Sprite?\nAI: Sure..\nCX: Can I get Spray?\nAI: Sure..",
+                     "completion": "1x Bean & Cheese Burrito with Green Sauce",
+                     "is_yes": False},
+                    {"prompt": "AI1: <welcome>\nAI2: Can I get you an iced drink today?\nCX: Yeah.\nAI2: Got it.\nAI1: What can we make fresh for your today?\nCX: I want a Bean & Cheese Burrito with Green sauce.\nAI1: Got it.\nAI2: Can I get a Bean & Cheese Burrito with green sauce?\nAI1: Sure.\nAI2: Got it..",
+                     "completion": "1x Bean & Cheese Burrito with Green Sauce",
+                     "is_yes": True},
+                    {"prompt": "CX: <welcome>\nAI: Hi, can I help you?\nCX: Yes, I'd like to talk to a live person.\nAI: Okay, I'll be right back.",
+                     "completion": "1x Bean & Cheese Burrito with Green Sauce",
+                     "is_yes": False}]
 
         return self.__filter_question("Does the customer order only the one item?", conversations, examples, None)
 
