@@ -1,10 +1,12 @@
 from powerml import PowerML
 import re
-from collections import Counter
+from collections import Counter, defaultdict
 import random
 from tqdm import tqdm
 import sys
 import os
+import nltk
+from nltk.stem import WordNetLemmatizer
 
 from powerml.model.PowerML import MAX_TOTAL_TOKENS
 
@@ -26,6 +28,8 @@ class CreateTopicsModel:
         sys.stderr = open(os.devnull, 'w')
         from transformers import GPT2Tokenizer
         from transformers.utils import logging
+        nltk.download('wordnet')
+        self.lemmatizer = WordNetLemmatizer()
         sys.stdout = sys.__stdout__
         sys.stderr = sys.__stderr__
 
@@ -90,6 +94,7 @@ class CreateTopicsModel:
             topic_counter.update(topics)
             sorted_topics = self.__sort_topics(topic_counter)
         topics = self.__get_topics(sorted_topics)
+        topics = self.__deduplicate_topics_with_keywords(topics)
         self.memo_topics[hash_docs] = topics
         return topics
 
@@ -99,14 +104,14 @@ class CreateTopicsModel:
     def __prompt_format(self, topic_type):
         prompt_dict = {"{{topic_type}}": topic_type}
         for i in range(self.sample_size):
-            key = "{{example" + str(i+1) + "}}"
+            key = "{{example" + str(i + 1) + "}}"
             prompt_dict[key] = ""
         return prompt_dict
 
     def __add_examples(self, examples, prompt, max_total_tokens=MAX_TOTAL_TOKENS):
         prompt_dict = prompt
         for i, example in enumerate(examples):
-            key = "{{example" + str(i+1) + "}}"
+            key = "{{example" + str(i + 1) + "}}"
             prompt_dict[key] = example
             if self.__count_tokens(str(prompt_dict)) > max_total_tokens - self.max_output_tokens:
                 prompt_dict[key] = ""
@@ -140,4 +145,16 @@ class CreateTopicsModel:
 
     def __get_topics(self, sorted_topics):
         # Return and save all topics
-        return [{"name": elt, "score": count/self.num_subsamples} for elt, count in sorted_topics]
+        return [{"name": elt, "score": count / self.num_subsamples} for elt, count in sorted_topics]
+    
+    def __deduplicate_topics_with_keywords(self, topics_with_scores):
+        related_topics = defaultdict(list)
+        for topic in topics_with_scores:
+            related_topics[self.lemmatizer.lemmatize(topic['name'].lower())].append(topic)
+        filtered_topics_with_scores = []
+        for topic_name in related_topics:
+            keywords = [related_topic['name'] for related_topic in related_topics[topic_name]]
+            score = sum([related_topic['score'] for related_topic in related_topics[topic_name]])
+            filtered_topics_with_scores.append({'name': topic_name, 'score': score, 'keywords': keywords})
+        filtered_topics_with_scores = sorted(filtered_topics_with_scores, key=lambda x: x['score'], reverse=True)
+        return filtered_topics_with_scores
