@@ -1,8 +1,7 @@
 import io
-import requests
+from typing import Tuple
 import jsonlines
-from powerml.utils.run_ai import query_powerml, powerml_train
-from powerml.utils.config import get_config
+from powerml.utils.run_ai import query_powerml, mutation_powerml_train, query_powerml_with_probability
 import logging
 
 logger = logging.getLogger(__name__)
@@ -20,7 +19,7 @@ class PowerML:
     '''
 
     def __init__(self, config={}):
-        self.config = get_config(config)
+        self.config = config
         self.current_model = "text-davinci-003"
 
     def predict(self,
@@ -28,7 +27,7 @@ class PowerML:
                 model: str = None,
                 stop: str = "",
                 max_tokens: int = 128,
-                temperature: int = 0,
+                temperature: float = 0.0,
                 ) -> str:
         if model == "" or model is None:
             model = self.current_model
@@ -39,20 +38,38 @@ class PowerML:
                              model=model,
                              stop=stop,
                              temperature=temperature,
-                             key=self.config["powerml.key"],
+                             config=self.config,
                              )
 
+    def predict_with_probability(self,
+                                 prompt,
+                                 model: str = None,
+                                 stop: str = "",
+                                 max_tokens: int = 128,
+                                 temperature: float = 0.0,
+                                 ) -> Tuple[str, float]:
+        if model == "" or model is None:
+            model = self.current_model
+        logger.debug("Predict using model: " + model)
+        # if the model is one of our models, then hit our api
+        return query_powerml_with_probability(prompt,
+                                              max_tokens=max_tokens,
+                                              model=model,
+                                              stop=stop,
+                                              temperature=temperature,
+                                              config=self.config,
+                                              )
+
     def fit(self,
             data: list[str],
-            model: str = None):
+            model: str = None,
+            name: str = None,
+            is_public: bool = False):
         if model == "" or model is None:
             model = self.current_model
         logger.debug("Fit using model: " + model)
-        params = {
-            "dataset": self.__make_dataset_string(data),
-            "model": model
-        }
-        response = powerml_train(params, self.config["powerml.key"])
+        dataset = self.__make_dataset_string(data)
+        response = mutation_powerml_train(dataset, name, model, is_public, self.config)
         model_details = response.json()['model']
         self.current_model = model_details["model_name"]
         return model_details
@@ -62,4 +79,5 @@ class PowerML:
         with jsonlines.Writer(string) as writer:
             for item in training_data:
                 writer.write({"prompt": item})
-        return string.getvalue()
+        val = string.getvalue()
+        return val
