@@ -8,10 +8,13 @@ def get_config(dictionary={}):
 
 
 def setup_config(dictionary):
-    return config.ConfigurationSet(
+    config_set = config.ConfigurationSet(
         config.config_from_dict(dictionary),
         home_yaml_config(),
+        config.config_from_env(
+            prefix="POWERML", separator="__", lowercase_keys=True),
     )
+    return config_set
 
 
 def home_yaml_config():
